---@meta

---@class cc.PhysicsShapeEdgeChain :cc.PhysicsShape
local PhysicsShapeEdgeChain={ }
cc.PhysicsShapeEdgeChain=PhysicsShapeEdgeChain




---* Get this chain's points array count.<br>
---* return An integer number.
---@return int
function PhysicsShapeEdgeChain:getPointsCount () end
---* Get this chain's center position.<br>
---* return A Vec2 object.
---@return vec2_table
function PhysicsShapeEdgeChain:getCenter () end