---@meta

---@class cc.TransitionJumpZoom :cc.TransitionScene
local TransitionJumpZoom={ }
cc.TransitionJumpZoom=TransitionJumpZoom




---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return A autoreleased TransitionJumpZoom object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionJumpZoom:create (t,scene) end
---* 
---@return self
function TransitionJumpZoom:TransitionJumpZoom () end