---@meta

---@class cc.StopGrid :cc.ActionInstant
local StopGrid={ }
cc.StopGrid=StopGrid




---* brief Create a StopGrid Action.<br>
---* return Return a pointer of StopGrid. When the creation failed, return nil.
---@return self
function StopGrid:create () end
---* 
---@param target cc.Node
---@return self
function StopGrid:startWithTarget (target) end
---* 
---@return self
function StopGrid:clone () end
---* 
---@return self
function StopGrid:reverse () end
---* 
---@return self
function StopGrid:StopGrid () end