---@meta

---@class cc.TransitionProgress :cc.TransitionScene
local TransitionProgress={ }
cc.TransitionProgress=TransitionProgress




---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return An autoreleased TransitionProgress object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionProgress:create (t,scene) end
---* 
---@return self
function TransitionProgress:TransitionProgress () end