---@meta

---@class cc.PhysicsShapeEdgePolygon :cc.PhysicsShape
local PhysicsShapeEdgePolygon={ }
cc.PhysicsShapeEdgePolygon=PhysicsShapeEdgePolygon




---* Get this polygon's points array count.<br>
---* return An integer number.
---@return int
function PhysicsShapeEdgePolygon:getPointsCount () end
---* Get this polygon's center position.<br>
---* return A Vec2 object.
---@return vec2_table
function PhysicsShapeEdgePolygon:getCenter () end