---@meta

---@class cc.ToggleVisibility :cc.ActionInstant
local ToggleVisibility={ }
cc.ToggleVisibility=ToggleVisibility




---*  Allocates and initializes the action.<br>
---* return An autoreleased ToggleVisibility object.
---@return self
function ToggleVisibility:create () end
---* 
---@return self
function ToggleVisibility:clone () end
---* param time In seconds.
---@param time float
---@return self
function ToggleVisibility:update (time) end
---* 
---@return self
function ToggleVisibility:reverse () end
---* 
---@return self
function ToggleVisibility:ToggleVisibility () end